jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/380100 )

Change subject: build: Updating mediawiki/mediawiki-codesniffer to 13.0.0
......................................................................


build: Updating mediawiki/mediawiki-codesniffer to 13.0.0

Change-Id: I1764037ea97a2e9c4dab6cfdc6a51ea66772b34b
---
M composer.json
M includes/CNDatabase.php
M includes/ChoiceDataProvider.php
3 files changed, 7 insertions(+), 7 deletions(-)

Approvals:
  Umherirrender: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/composer.json b/composer.json
index 41bb0d7..7df3c8d 100644
--- a/composer.json
+++ b/composer.json
@@ -2,7 +2,7 @@
        "require-dev": {
                "jakub-onderka/php-parallel-lint": "0.9.2",
                "jakub-onderka/php-console-highlighter": "0.3.2",
-               "mediawiki/mediawiki-codesniffer": "0.12.0"
+               "mediawiki/mediawiki-codesniffer": "13.0.0"
        },
        "scripts": {
                "fix": "phpcbf",
diff --git a/includes/ChoiceDataProvider.php b/includes/ChoiceDataProvider.php
index 1f43221..2bf7981 100644
--- a/includes/ChoiceDataProvider.php
+++ b/includes/ChoiceDataProvider.php
@@ -43,11 +43,11 @@
                        self::CACHE_TTL,
                        function ( $oldValue, &$ttl, array &$setOpts )
                                use ( $project, $language ) {
-                               $dbr = CNDatabase::getDb( DB_SLAVE );
+                               $dbr = CNDatabase::getDb( DB_REPLICA );
 
-                               // Account for slave lag to prevent a race 
condition when
+                               // Account for replica lag to prevent a race 
condition when
                                // campaigns are updated, the cache is 
invalidated, and
-                               // a client queries a yet-unsynced slave DB. 
Also, gracefully
+                               // a client queries a yet-unsynced replica DB. 
Also, gracefully
                                // fail if we're running an old version of core 
(<1.27).
                                if ( method_exists( 'Database', 
'getCacheSetOptions' ) ) {
                                        $setOpts += 
Database::getCacheSetOptions( $dbr );

diff --git a/includes/CNDatabase.php b/includes/CNDatabase.php
index 8355dab..28a7bee 100644
--- a/includes/CNDatabase.php
+++ b/includes/CNDatabase.php
@@ -18,7 +18,7 @@
         * metawiki for WMF sister projects. Note that the infrastructure DB 
does
         * not support table prefixes if running in multi-database mode.
         *
         * @param int $target Set to DB_MASTER or DB_SLAVE to force a connection
connection
         * to that database.  If no parameter is given, we attempt to choose a
         * sane default (see above).
         *
@@ -45,9 +45,9 @@
                        $target = DB_MASTER;
                }
 
                // If target is still null, use DB_SLAVE.
                if ( $target === null ) {
-                       $target = DB_SLAVE;
+                       $target = DB_REPLICA;
                }
 
                // If we got DB_MASTER for whatever reason, make sure that's 
@@ -18,7 +18,7 @@
         * not support table prefixes if running in multi-database mode.
         *
-        * @param int $target Set to DB_MASTER or DB_SLAVE to force a connection
+        * @param int $target Set to DB_MASTER or DB_REPLICA to force a 
connection
         * to that database.  If no parameter is given, we attempt to choose a
@@ -45,9 +45,9 @@
                }
 
-               // If target is still null, use DB_SLAVE.
+               // If target is still null, use DB_REPLICA.
                if ( $target === null ) {
remembered
-- 
To view, visit https://gerrit.wikimedia.org/r/380100
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I1764037ea97a2e9c4dab6cfdc6a51ea66772b34b
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/extensions/CentralNotice
Gerrit-Branch: master
Gerrit-Owner: Libraryupgrader <[email protected]>
Gerrit-Reviewer: AndyRussG <[email protected]>
Gerrit-Reviewer: Ejegg <[email protected]>
Gerrit-Reviewer: Umherirrender <[email protected]>
Gerrit-Reviewer: XenoRyet <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to